Crate simple_dst

Crate simple_dst 

Traits and derive macros for allocating and using DSTs.

The design is inspired by the great slice-dst crate, but with more of a focus on implementability and use of modern Rust features.

Subject to breaking changes until the crate hits 1.0, which will only be possible once Rust stabilises the ptr_metadata and clone_to_uninit features.

Traits

AllocDst
Type that can allocate a DST and store it inside it.
CloneToUninit
A generalization of Clone to dynamically-sized types stored in arbitrary containers.
Dst
A dynamically sized type.

Derive Macros

CloneToUninit
Derive macro for the CloneToUninit trait for DSTs.
Dst
Derive macro for the Dst trait.
ToOwned