Traits and derive macros for allocating and using DSTs.
The design is inspired by the great slice-dst crate, but with more of a focus on implementability and use of modern Rust features.
Subject to breaking changes until the crate hits 1.0, which will only be possible
once Rust stabilises the ptr_metadata and clone_to_uninit features.
Traits
- Alloc
Dst - Type that can allocate a DST and store it inside it.
- Clone
ToUninit - A generalization of
Cloneto dynamically-sized types stored in arbitrary containers. - Dst
- A dynamically sized type.
Derive Macros
- Clone
ToUninit - Derive macro for the
CloneToUninittrait for DSTs. - Dst
- Derive macro for the
Dsttrait. - ToOwned